@@ -353,20 +353,34 @@ class VLBIFileReaderBase(FileBase):
         AssertionError
             If the header did not pass verification.
         """
-        locations = self.locate_frames(*args, **kwargs)
-        if not locations:
-            raise HeaderNotFoundError('could not locate a a nearby frame.')
-        self.seek(locations[0])
-        with self.temporary_offset():
-            return self.read_header()
+        for location in self.locate_frames(*args, **kwargs):
+            with self.temporary_offset(location):
+                try:
+                    header = self.read_header()
+                except Exception:
+                    continue
+                else:
+                    break
 
-    def get_frame_rate(self):
+        else:
+            raise HeaderNotFoundError('could not locate a a nearby frame.')
+
+        self.seek(location)
+        return header
+
+    def get_frame_rate(self, offset=0):
         """Determine the number of frames per second.
 
         The method cycles through headers, starting from the start of the file,
         finding the largest frame number before it jumps back to 0 for a new
         second.
 
+        Parameters
+        ----------
+        offset : int or None, optional
+            Offset at which to start searching.  Default is 0, i.e., the start
+            of the file. Use `None` to start at the current position.
+
         Returns
         -------
         frame_rate : `~astropy.units.Quantity`
@@ -377,7 +391,7 @@ class VLBIFileReaderBase(FileBase):
         `EOFError`
             If the file contains less than one second of data.
         """
-        with self.temporary_offset(0):
+        with self.temporary_offset(offset):
             header = header0 = self.read_header()
             frame_nr0 = header0['frame_nr']
             while header['frame_nr'] == frame_nr0:
@@ -1379,7 +1393,14 @@ class FileInfo:
             used_kwargs = {key: kwargs[key] for key in info.missing
                            if key in kwargs}
             if used_kwargs:
-                info = self._get_info(name, mode='rb', **used_kwargs)
+                info2 = self._get_info(name, mode='rb', **used_kwargs)
+                if self.is_ok(info2):
+                    info = info2
+                else:
+                    # An exception due to the arguments must have occurred.
+                    info.missing = {k: v for (k, v) in kwargs.items()
+                                    if k not in used_kwargs}
+                    info.errors[f"kwargs={kwargs}"] = info2
 
             info.used_kwargs = used_kwargs
 
