@@ -816,7 +816,7 @@ class TestGUPPI:
 
 
 class TestGUPPIFileNameSequencer:
-    def setup(self):
+    def setup_class(self):
         with open(SAMPLE_FILE, 'rb') as fh:
             self.header = guppi.GUPPIHeader.fromfile(fh)
 
